# 自动HTML创建器

> 这是一个解耦了的HTML创建器,利用简单的几句Python代码你就可以创建一个完整的HTML页面,由于是解耦的,你不需要再考虑将来HTML的升级和浏览器的兼容性(一部分还未实现)

this package is use for creating html by python

[github](https://github.com/normidar/HtmlCreator)

